@@ -2,6 +2,11 @@ from datetime import datetime
 
 from . import Base
 from sqlalchemy import Column, DateTime, ForeignKey, Integer, String
+from sqlalchemy.orm import relationship
+
+# AvailabilityRequest class is used, so we must define it here or else it has to be definied by clients of the used class,
+# and they don't necessarily know that they need to do this
+from .availability_request import AvailabilityRequest
 
 
 # Note from the future,
@@ -28,6 +33,8 @@ class Availability(Base):
 
     requests = relationship("AvailabilityRequest", cascade="all, delete, delete-orphan")
 
+    repeatingAvailability = Column(Integer, ForeignKey('repeating_availability.id'), nullable=True)
+
     def __init__(self, subjects, startTime, endTime, tutor):
         self.subjects = subjects
         self.startTime = startTime
